@@ -7,7 +7,7 @@ package Tk::DateEntry;
 
 use vars qw($VERSION $DEBUG);
 
-$VERSION = '1.40';
+$VERSION = '1.41';
 
 use Tk;
 use strict;
@@ -242,9 +242,7 @@ sub configure
 	# changes.
 	my $daynames;
 	if ($args{-daynames} && $args{-daynames} eq 'locale' && defined &strftime) {
-	    foreach (0..6) {
-		push @$daynames, $w->_decode_posix_bytes(strftime("%a",0,0,0,1,1,1,$_));
-	    }
+	    $daynames = [ $w->_get_locale_daynames ];
 	} else {
 	    $daynames = $w->cget('-daynames');
 	}
@@ -742,6 +740,17 @@ sub updateDateDC
     }
 }
 
+sub _get_locale_daynames {
+    my($w) = @_;
+    my @daynames;
+    my @l = (0,0,0,1,1-1,106,0);
+    for (0..6) {
+	$daynames[$l[6]] = $w->_decode_posix_bytes(strftime('%a', @l));
+	$l[3]++; $l[6]++;
+    }
+    @daynames;
+}
+
 # "Stolen" from Locale::Maketext::Lexicon (called "encoding" there)
 # and slightly adapted.
 sub _posix_encoding {
@@ -795,13 +804,15 @@ sub _posix_encoding {
 
 sub _decode_posix_bytes {
     my($w, $string) = @_;
-    my $codeset = $w->_posix_encoding;
-    if ($codeset) {
-	eval {
-	    require Encode;
-	    $string = Encode::decode($codeset, $string);
-	};
-	warn "Cannot decode string '$string' in codeset '$codeset': $@" if $@;
+    if ($] < 5.022) {
+	my $codeset = $w->_posix_encoding;
+	if ($codeset) {
+	    eval {
+		require Encode;
+		$string = Encode::decode($codeset, $string);
+	    };
+	    warn "Cannot decode string '$string' in codeset '$codeset': $@" if $@;
+	}
     }
     $string;
 }
